@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
-# Copyright 2020-2021 Univention GmbH
+# Copyright 2020-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -48,30 +48,30 @@ def mocked_conn(mocker, lo, pos):
 
 
 @pytest.fixture
-def selfservice_ucr(mocker, ucr):
+def selfservice_ucr(mocker, mock_ucr):
 	from univentionunittests.umc import import_umc_module
 	from univention.config_registry import ConfigRegistry
 	selfservice = import_umc_module('passwordreset')
-	mocker.patch.object(selfservice, 'ucr', ucr)
+	mocker.patch.object(selfservice, 'ucr', mock_ucr)
 
 	def inject_fake_ucr(self):
 		self.clear()
-		self.update(ucr.items)
+		self.update(mock_ucr.items)
 	mocker.patch.object(ConfigRegistry, 'load', inject_fake_ucr)
 	mocker.patch.object(ConfigRegistry, '__enter__', side_effect=ValueError("You may not save a faked UCR"))
-	ucr['umc/self-service/enabled'] = 'yes'
-	ucr['umc/self-service/passwordreset/email/enabled'] = 'yes'
-	ucr['umc/self-service/account-deregistration/blacklist/groups'] = 'Administrators,Domain Admins'
-	ucr['umc/self-service/account-deregistration/blacklist/users'] = ''
-	ucr['umc/self-service/account-deregistration/whitelist/groups'] = 'Domain Users'
-	ucr['umc/self-service/account-deregistration/whitelist/users'] = ''
-	ucr['umc/self-service/passwordreset/blacklist/groups'] = 'Administrators,Domain Admins'
-	ucr['umc/self-service/passwordreset/whitelist/groups'] = 'Domain Users'
-	ucr['umc/self-service/profiledata/blacklist/groups'] = 'Administrators,Domain Admins'
-	ucr['umc/self-service/profiledata/blacklist/users'] = ''
-	ucr['umc/self-service/profiledata/whitelist/groups'] = 'Domain Users'
-	ucr['umc/self-service/profiledata/whitelist/users'] = ''
-	return ucr
+	mock_ucr['umc/self-service/enabled'] = 'yes'
+	mock_ucr['umc/self-service/passwordreset/email/enabled'] = 'yes'
+	mock_ucr['umc/self-service/account-deregistration/blacklist/groups'] = 'Administrators,Domain Admins'
+	mock_ucr['umc/self-service/account-deregistration/blacklist/users'] = ''
+	mock_ucr['umc/self-service/account-deregistration/whitelist/groups'] = 'Domain Users'
+	mock_ucr['umc/self-service/account-deregistration/whitelist/users'] = ''
+	mock_ucr['umc/self-service/passwordreset/blacklist/groups'] = 'Administrators,Domain Admins'
+	mock_ucr['umc/self-service/passwordreset/whitelist/groups'] = 'Domain Users'
+	mock_ucr['umc/self-service/profiledata/blacklist/groups'] = 'Administrators,Domain Admins'
+	mock_ucr['umc/self-service/profiledata/blacklist/users'] = ''
+	mock_ucr['umc/self-service/profiledata/whitelist/groups'] = 'Domain Users'
+	mock_ucr['umc/self-service/profiledata/whitelist/users'] = ''
+	return mock_ucr
 
 
 @pytest.fixture
